@@ -1,6 +1,6 @@
 /*
  * ProFTPD - mod_proxy reverse proxy implementation
- * Copyright (c) 2012-2020 TJ Saunders
+ * Copyright (c) 2012-2022 TJ Saunders
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -781,12 +781,27 @@ static int reverse_try_connect(pool *p, struct proxy_session *proxy_sess,
   proxy_sess->dst_pconn = pconn;
   proxy_sess->other_addrs = other_addrs;
 
-  uri_tls = proxy_conn_get_tls(pconn);
-  if (uri_tls == PROXY_TLS_ENGINE_IMPLICIT) {
-    pr_trace_msg(trace_channel, 9, "%s#%u requesting, using implicit FTPS",
-      pr_netaddr_get_ipstr(dst_addr),
-      (unsigned int) ntohs(pr_netaddr_get_port(dst_addr)));
-    proxy_tls_set_tls(uri_tls);
+  /* Carefully handle FTP-isms here; we may be proxying SSH instead.
+   *
+   * NOTE: All of these FTP-specific cases should be refactored into the
+   * the FTP client API, e.g. proxy_ftp_ctrl_on_connect().
+   *
+   * NOTE: Should we consider using the SSH client API to do the version
+   * exchange there?
+   */
+
+  if (proxy_sess->use_ftp == TRUE) {
+    if (proxy_tls_using_tls() == PROXY_TLS_ENGINE_MATCH_CLIENT) {
+      proxy_tls_match_client_tls();
+    }
+
+    uri_tls = proxy_conn_get_tls(pconn);
+    if (uri_tls == PROXY_TLS_ENGINE_IMPLICIT) {
+      pr_trace_msg(trace_channel, 9, "%s#%u requesting, using implicit FTPS",
+        pr_netaddr_get_ipstr(dst_addr),
+        (unsigned int) ntohs(pr_netaddr_get_port(dst_addr)));
+      proxy_tls_set_tls(uri_tls);
+    }
   }
 
   pr_gettimeofday_millis(&connecting_ms);
@@ -867,52 +882,58 @@ static int reverse_try_connect(pool *p, struct proxy_session *proxy_sess,
   proxy_sess->frontend_ctrl_conn = session.c;
   proxy_sess->backend_ctrl_conn = server_conn;
 
-  use_tls = proxy_tls_using_tls();
+  if (proxy_sess->use_ftp == TRUE) {
+    use_tls = proxy_tls_using_tls();
 
-  /* Handle implicit FTPS connects. */
-  if (use_tls == PROXY_TLS_ENGINE_IMPLICIT) {
-    if (reverse_tls_postopen(p, proxy_sess, server_conn) < 0) {
-      return -1;
+    /* Handle implicit FTPS connects. */
+    if (use_tls == PROXY_TLS_ENGINE_IMPLICIT) {
+      if (reverse_tls_postopen(p, proxy_sess, server_conn) < 0) {
+        return -1;
+      }
     }
-  }
 
-  /* XXX Support/send a CLNT command of our own?  Configurable via e.g.
-   * "UserAgent" string?
-   */
+    /* XXX Support/send a CLNT command of our own?  Configurable via e.g.
+     * "UserAgent" string?
+     */
 
-  resp = proxy_ftp_ctrl_recv_resp(p, server_conn, &resp_nlines, 0);
-  if (resp == NULL) {
-    xerrno = errno;
+    resp = proxy_ftp_ctrl_recv_resp(p, server_conn, &resp_nlines, 0);
+    if (resp == NULL) {
+      xerrno = errno;
 
-    pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-      "unable to read banner from server %s:%u: %s",
-      pr_netaddr_get_ipstr(server_conn->remote_addr),
-      ntohs(pr_netaddr_get_port(server_conn->remote_addr)), strerror(xerrno));
+      pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+        "unable to read banner from server %s:%u: %s",
+        pr_netaddr_get_ipstr(server_conn->remote_addr),
+        ntohs(pr_netaddr_get_port(server_conn->remote_addr)), strerror(xerrno));
 
-    errno = xerrno;
-    return -1;
+      errno = xerrno;
+      return -1;
+
+    } else {
+      int banner_ok = TRUE;
+
+      pr_gettimeofday_millis(&connected_ms);
+
+      if (resp->num[0] != '2') {
+        banner_ok = FALSE;
+      }
+
+      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+        "received banner from backend %s:%u%s: %s %s",
+        pr_netaddr_get_ipstr(server_conn->remote_addr),
+        ntohs(pr_netaddr_get_port(server_conn->remote_addr)),
+        banner_ok ? "" : ", DISCONNECTING", resp->num, resp->msg);
+
+      if (banner_ok == FALSE) {
+        pr_inet_close(p, server_conn);
+        proxy_sess->backend_ctrl_conn = NULL;
+        errno = EPERM;
+        return -1;
+      }
+    }
 
   } else {
-    int banner_ok = TRUE;
-
     pr_gettimeofday_millis(&connected_ms);
-
-    if (resp->num[0] != '2') {
-      banner_ok = FALSE;
-    }
-
-    (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-      "received banner from backend %s:%u%s: %s %s",
-      pr_netaddr_get_ipstr(server_conn->remote_addr),
-      ntohs(pr_netaddr_get_port(server_conn->remote_addr)),
-      banner_ok ? "" : ", DISCONNECTING", resp->num, resp->msg);
-
-    if (banner_ok == FALSE) {
-      pr_inet_close(p, server_conn);
-      proxy_sess->backend_ctrl_conn = NULL;
-      errno = EPERM;
-      return -1;
-    }
+    use_tls = PROXY_TLS_ENGINE_OFF;
   }
 
   pr_trace_msg(trace_channel, 8,
@@ -927,64 +948,72 @@ static int reverse_try_connect(pool *p, struct proxy_session *proxy_sess,
       strerror(errno));
   }
 
-  /* Get the features supported by the backend server. */
-  if (proxy_ftp_sess_get_feat(p, proxy_sess) < 0) {
-    if (errno != EPERM) {
-      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-        "unable to determine features of backend server: %s", strerror(errno));
-    }
-  }
-
-  pr_response_block(TRUE);
-
-  if (use_tls != PROXY_TLS_ENGINE_OFF &&
-      use_tls != PROXY_TLS_ENGINE_IMPLICIT) {
-    if (proxy_ftp_sess_send_auth_tls(p, proxy_sess) < 0 &&
-        errno != ENOSYS) {
-      xerrno = errno;
-
-      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-        "error enabling TLS on control connection to backend server: %s",
-        strerror(xerrno));
-      pr_inet_close(p, server_conn);
-      proxy_sess->backend_ctrl_conn = NULL;
-
-      pr_response_block(FALSE);
-      errno = xerrno;
-      return -1;
+  if (proxy_sess->use_ftp == TRUE) {
+    /* Get the features supported by the backend server. */
+    if (proxy_ftp_sess_get_feat(p, proxy_sess) < 0) {
+      if (errno != EPERM) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "unable to determine features of backend server: %s",
+          strerror(errno));
+      }
     }
 
-    use_tls = proxy_tls_using_tls();
-  }
-
-  if (use_tls != PROXY_TLS_ENGINE_OFF &&
-      use_tls != PROXY_TLS_ENGINE_IMPLICIT) {
-    if (reverse_tls_postopen(p, proxy_sess, server_conn) < 0) {
-      return -1;
-    }
-  }
-
-  if (use_tls != PROXY_TLS_ENGINE_OFF) {
-    if (proxy_sess_state & PROXY_SESS_STATE_BACKEND_HAS_CTRL_TLS) {
-      /* NOTE: should this be a fatal error? */
-      (void) proxy_ftp_sess_send_pbsz_prot(p, proxy_sess);
-    }
-  }
-
-  if (reverse_flags == PROXY_REVERSE_FL_CONNECT_AT_SESS_INIT) {
-    pr_response_block(FALSE);
-  }
-
-  if (proxy_ftp_ctrl_send_resp(p, session.c, resp, resp_nlines) < 0) {
-    (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-      "unable to send banner to client: %s", strerror(errno));
-  }
-
-  if (reverse_flags == PROXY_REVERSE_FL_CONNECT_AT_SESS_INIT) {
     pr_response_block(TRUE);
-  }
 
-  (void) proxy_ftp_sess_send_host(p, proxy_sess);
+    if (use_tls != PROXY_TLS_ENGINE_OFF &&
+        use_tls != PROXY_TLS_ENGINE_IMPLICIT) {
+      if (proxy_ftp_sess_send_auth_tls(p, proxy_sess) < 0 &&
+          errno != ENOSYS) {
+        xerrno = errno;
+
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "error enabling TLS on control connection to backend server: %s",
+          strerror(xerrno));
+        pr_inet_close(p, server_conn);
+        proxy_sess->backend_ctrl_conn = NULL;
+
+        pr_response_block(FALSE);
+        errno = xerrno;
+        return -1;
+      }
+
+      use_tls = proxy_tls_using_tls();
+    }
+
+    if (use_tls != PROXY_TLS_ENGINE_OFF &&
+        use_tls != PROXY_TLS_ENGINE_IMPLICIT) {
+      if (reverse_tls_postopen(p, proxy_sess, server_conn) < 0) {
+        return -1;
+      }
+    }
+
+    if (use_tls != PROXY_TLS_ENGINE_OFF) {
+      if (proxy_sess_state & PROXY_SESS_STATE_BACKEND_HAS_CTRL_TLS) {
+        /* NOTE: should this be a fatal error? */
+        (void) proxy_ftp_sess_send_pbsz_prot(p, proxy_sess);
+      }
+    }
+
+    if (reverse_flags == PROXY_REVERSE_FL_CONNECT_AT_SESS_INIT) {
+      pr_response_block(FALSE);
+    }
+
+    /* Only send the banner if we haven't done so already; the banner
+     * might already have been sent due to e.g. TLS SNI.
+     */
+    if (pr_table_get(session.notes, "mod_tls.sni", NULL) == NULL) {
+      if (proxy_ftp_ctrl_send_resp(p, session.c, resp, resp_nlines) < 0) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "unable to send banner to client: %s", strerror(errno));
+      }
+    }
+
+    if (reverse_flags == PROXY_REVERSE_FL_CONNECT_AT_SESS_INIT) {
+      pr_response_block(TRUE);
+    }
+
+    (void) proxy_ftp_sess_send_host(p, proxy_sess);
+  }
 
   /* Populate the session notes about this connection. */
   memset(port_text, '\0', sizeof(port_text));
@@ -1002,14 +1031,21 @@ static int reverse_try_connect(pool *p, struct proxy_session *proxy_sess,
   return 0;
 }
 
-static int reverse_connect(pool *p, struct proxy_session *proxy_sess) {
+int proxy_reverse_connect(pool *p, struct proxy_session *proxy_sess,
+    const void *connect_data) {
   register int i;
   int res;
 
+  if (p == NULL ||
+      proxy_sess == NULL) {
+    errno = EINVAL;
+    return -1;
+  }
+
   for (i = 0; i < reverse_retry_count; i++) {
     pr_signals_handle();
 
-    res = reverse_try_connect(p, proxy_sess, NULL);
+    res = reverse_try_connect(p, proxy_sess, connect_data);
     if (res == 0) {
       return 0;
     }
@@ -1308,7 +1344,7 @@ int proxy_reverse_sess_init(pool *p, const char *tables_dir,
   }
 
   if (reverse_flags == PROXY_REVERSE_FL_CONNECT_AT_SESS_INIT) {
-    res = reverse_connect(p, proxy_sess);
+    res = proxy_reverse_connect(p, proxy_sess, NULL);
     if (res < 0) {
       return -1;
     }
@@ -1536,34 +1572,38 @@ array_header *proxy_reverse_json_parse_uris(pool *p, const char *path,
   return uris;
 }
 
-int proxy_reverse_connect_get_policy(const char *policy) {
+int proxy_reverse_get_connect_policy(void) {
+  return reverse_connect_policy;
+}
+
+int proxy_reverse_connect_get_policy_id(const char *policy) {
   if (policy == NULL) {
     errno = EINVAL;
     return -1;
   }
 
-  if (strncasecmp(policy, "Random", 7) == 0) {
+  if (strcasecmp(policy, "Random") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_RANDOM;
 
-  } else if (strncasecmp(policy, "RoundRobin", 11) == 0) {
+  } else if (strcasecmp(policy, "RoundRobin") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_ROUND_ROBIN;
 
-  } else if (strncasecmp(policy, "Shuffle", 8) == 0) {
+  } else if (strcasecmp(policy, "Shuffle") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_SHUFFLE;
 
-  } else if (strncasecmp(policy, "LeastConns", 11) == 0) {
+  } else if (strcasecmp(policy, "LeastConns") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_LEAST_CONNS;
 
-  } else if (strncasecmp(policy, "PerUser", 8) == 0) {
+  } else if (strcasecmp(policy, "PerUser") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_PER_USER;
 
-  } else if (strncasecmp(policy, "PerGroup", 9) == 0) {
+  } else if (strcasecmp(policy, "PerGroup") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_PER_GROUP;
 
-  } else if (strncasecmp(policy, "PerHost", 8) == 0) {
+  } else if (strcasecmp(policy, "PerHost") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_PER_HOST;
 
-  } else if (strncasecmp(policy, "LeastResponseTime", 18) == 0) {
+  } else if (strcasecmp(policy, "LeastResponseTime") == 0) {
     return PROXY_REVERSE_CONNECT_POLICY_LEAST_RESPONSE_TIME;
   }
 
@@ -1668,27 +1708,18 @@ int proxy_reverse_handle_user(cmd_rec *cmd, struct proxy_session *proxy_sess,
   }
 
   if (reverse_flags == PROXY_REVERSE_FL_CONNECT_AT_USER) {
-    register int i;
     int connected = FALSE, xerrno = 0;
 
-    for (i = 0; i < reverse_retry_count; i++) {
-      pr_signals_handle();
+    res = proxy_reverse_connect(proxy_pool, proxy_sess, cmd->arg);
+    xerrno = errno;
 
-      res = reverse_try_connect(proxy_pool, proxy_sess, cmd->arg);
-      if (res == 0) {
-        connected = TRUE;
-        break;
-      }
-
-      xerrno = errno;
+    if (res == 0) {
+      connected = TRUE;
     }
 
     pr_response_block(FALSE);
 
     if (connected == FALSE) {
-      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-        "ProxyRetryCount %d reached with no successful connection, failing",
-        reverse_retry_count);
       *successful = FALSE;
 
       if (xerrno != EINVAL) {
@@ -1844,14 +1875,13 @@ int proxy_reverse_handle_pass(cmd_rec *cmd, struct proxy_session *proxy_sess,
         return -1;
       }
 
-      if (session.auth_mech) {
+      if (session.auth_mech != NULL) {
         pr_log_debug(DEBUG2, "user '%s' authenticated by %s", user,
           session.auth_mech);
       }
     }
 
     if (!(proxy_sess_state & PROXY_SESS_STATE_CONNECTED)) {
-      register int i;
       int connected = FALSE;
       const char *user = NULL, *connect_name = NULL;
       cmd_rec *user_cmd;
@@ -1873,24 +1903,16 @@ int proxy_reverse_handle_pass(cmd_rec *cmd, struct proxy_session *proxy_sess,
         }
       }
 
-      for (i = 0; i < reverse_retry_count; i++) {
-        pr_signals_handle();
+      res = proxy_reverse_connect(proxy_pool, proxy_sess, connect_name);
+      xerrno = errno;
 
-        res = reverse_try_connect(proxy_pool, proxy_sess, connect_name);
-        if (res == 0) {
-          connected = TRUE;
-          break;
-        }
-
-        xerrno = errno;
+      if (res == 0) {
+        connected = TRUE;
       }
 
       pr_response_block(FALSE);
 
       if (connected == FALSE) {
-        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-          "ProxyRetryCount %d reached with no successful connection, failing",
-          reverse_retry_count);
         *successful = FALSE;
 
         if (xerrno != EINVAL) {
