@@ -61,6 +61,8 @@ static int dispatch_user_cmd(pool *p, const char *orig_user,
   user_cmd->cmd_class = CL_AUTH|CL_SSH;
   user_cmd->arg = (char *) orig_user;
 
+  pr_response_set_pool(user_cmd->pool);
+
   /* Dispatch these as PRE_CMDs, so that mod_delay's tactics can be used
    * to ameliorate any timing-based attacks.
    */
@@ -71,6 +73,8 @@ static int dispatch_user_cmd(pool *p, const char *orig_user,
 
     dispatch_cmd_err(user_cmd);
     destroy_pool(user_cmd->pool);
+    pr_response_set_pool(NULL);
+
     return -1;
   }
 
@@ -84,6 +88,8 @@ static int dispatch_user_cmd(pool *p, const char *orig_user,
   pr_response_clear(&resp_list);
 
   destroy_pool(user_cmd->pool);
+  pr_response_set_pool(NULL);
+
   return 0;
 }
 
@@ -94,6 +100,8 @@ static int dispatch_pass_cmd(pool *p, int success) {
   pass_cmd->cmd_class = CL_AUTH|CL_SSH;
   pass_cmd->arg = pstrdup(pass_cmd->pool, "(hidden)");
 
+  pr_response_set_pool(pass_cmd->pool);
+
   if (success == TRUE) {
     pr_cmd_dispatch_phase(pass_cmd, POST_CMD, 0);
     pr_cmd_dispatch_phase(pass_cmd, LOG_CMD, 0);
@@ -104,7 +112,9 @@ static int dispatch_pass_cmd(pool *p, int success) {
   }
 
   pr_response_clear(&resp_list);
+
   destroy_pool(pass_cmd->pool);
+  pr_response_set_pool(NULL);
   return 0;
 }
 
@@ -119,8 +129,8 @@ static struct proxy_ssh_packet *read_auth_packet(pool *p,
   proxy_ssh_packet_get_poll_attempts(&poll_attempts);
   proxy_ssh_packet_get_poll_timeout(&poll_timeout_secs, &poll_timeout_ms);
 
-  proxy_ssh_packet_set_poll_attempts(1);
-  proxy_ssh_packet_set_poll_timeout(0, 50);
+  proxy_ssh_packet_set_poll_attempts(3);
+  proxy_ssh_packet_set_poll_timeout(0, 250);
 
   pkt = proxy_ssh_packet_create(p);
   res = proxy_ssh_packet_read(proxy_sess->backend_ctrl_conn, pkt);
@@ -293,7 +303,11 @@ static int write_userauth_hostbased(struct proxy_ssh_packet *pkt,
   len += proxy_ssh_msg_write_string(&buf, &buflen, pstrdup(pkt->pool,
     "hostbased"));
 
-  if (proxy_ssh_keys_have_hostkey(PROXY_SSH_KEY_ED25519) == 0) {
+  if (proxy_ssh_keys_have_hostkey(PROXY_SSH_KEY_ED448) == 0) {
+    use_hostkey_type = PROXY_SSH_KEY_ED448;
+    hostkey_algo = "ssh-ed448";
+
+  } else if (proxy_ssh_keys_have_hostkey(PROXY_SSH_KEY_ED25519) == 0) {
     use_hostkey_type = PROXY_SSH_KEY_ED25519;
     hostkey_algo = "ssh-ed25519";
 
