@@ -45,6 +45,7 @@ struct proxy_ssh_cipher {
   unsigned char *key;
   uint32_t key_len;
 
+  uint32_t auth_len;
   size_t discard_len;
 };
 
@@ -55,20 +56,25 @@ struct proxy_ssh_cipher {
  */
 
 static struct proxy_ssh_cipher read_ciphers[2] = {
-  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0 },
-  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0 }
+  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0, 0 },
+  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0, 0 }
 };
 static EVP_CIPHER_CTX *read_ctxs[2];
 
 static struct proxy_ssh_cipher write_ciphers[2] = {
-  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0 },
-  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0 }
+  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0, 0 },
+  { NULL, NULL, NULL, NULL, 0, NULL, 0, 0, 0 }
 };
 static EVP_CIPHER_CTX *write_ctxs[2];
 
 #define PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ		8
 
-static size_t cipher_blockszs[2] = {
+static size_t read_blockszs[2] = {
+  PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ,
+  PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ,
+};
+
+static size_t write_blockszs[2] = {
   PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ,
   PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ,
 };
@@ -111,7 +117,7 @@ static void switch_read_cipher(void) {
         "error clearing cipher context: %s", proxy_ssh_crypto_get_errors());
     }
  
-    cipher_blockszs[read_cipher_idx] = PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ; 
+    read_blockszs[read_cipher_idx] = PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ;
 
     /* Now we can switch the index. */
     if (read_cipher_idx == 1) {
@@ -138,7 +144,7 @@ static void switch_write_cipher(void) {
         "error clearing cipher context: %s", proxy_ssh_crypto_get_errors());
     }
 
-    cipher_blockszs[write_cipher_idx] = PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ;
+    write_blockszs[write_cipher_idx] = PROXY_SSH_CIPHER_DEFAULT_BLOCK_SZ;
 
     /* Now we can switch the index. */
     if (write_cipher_idx == 1) {
@@ -408,13 +414,62 @@ static int set_cipher_discarded(struct proxy_ssh_cipher *cipher,
   return 0;
 }
 
-size_t proxy_ssh_cipher_get_block_size(void) {
-  return cipher_blockszs[read_cipher_idx];
+/* These accessors to get the authenticated data length for the read, write
+ * ciphers are used during packet IO, and thus do not return the AAD lengths
+ * until those ciphers are keyed.
+ *
+ * However, during KEX, there are times when we want to know the ADD lengths
+ * after the algorithms are selected, but before they are keyed.  Thus for
+ * those cases, we have the accessor variants.
+ */
+
+size_t proxy_ssh_cipher_get_read_auth_size2(void) {
+  return read_ciphers[read_cipher_idx].auth_len;
 }
 
-void proxy_ssh_cipher_set_block_size(size_t blocksz) {
-  if (blocksz > cipher_blockszs[read_cipher_idx]) {
-    cipher_blockszs[read_cipher_idx] = blocksz;
+size_t proxy_ssh_cipher_get_read_auth_size(void) {
+  /* Do not indicate the read cipher authentication tag size until the
+   * cipher has been keyed.
+   */
+  if (read_ciphers[read_cipher_idx].key != NULL) {
+    return proxy_ssh_cipher_get_read_auth_size2();
+  }
+
+  return 0;
+}
+
+size_t proxy_ssh_cipher_get_write_auth_size2(void) {
+  return write_ciphers[write_cipher_idx].auth_len;
+}
+
+size_t proxy_ssh_cipher_get_write_auth_size(void) {
+  /* Do not indicate the write cipher authentication tag size until the
+   * cipher has been keyed.
+   */
+  if (write_ciphers[write_cipher_idx].key != NULL) {
+    return proxy_ssh_cipher_get_write_auth_size2();
+  }
+
+  return 0;
+}
+
+size_t proxy_ssh_cipher_get_read_block_size(void) {
+  return read_blockszs[read_cipher_idx];
+}
+
+size_t proxy_ssh_cipher_get_write_block_size(void) {
+  return write_blockszs[write_cipher_idx];
+}
+
+void proxy_ssh_cipher_set_read_block_size(size_t blocksz) {
+  if (blocksz > read_blockszs[read_cipher_idx]) {
+    read_blockszs[read_cipher_idx] = blocksz;
+  }
+}
+
+void proxy_ssh_cipher_set_write_block_size(size_t blocksz) {
+  if (blocksz > write_blockszs[write_cipher_idx]) {
+    write_blockszs[write_cipher_idx] = blocksz;
   }
 }
 
@@ -429,7 +484,7 @@ const char *proxy_ssh_cipher_get_read_algo(void) {
 
 int proxy_ssh_cipher_set_read_algo(pool *p, const char *algo) {
   unsigned int idx = read_cipher_idx;
-  size_t key_len = 0, discard_len = 0;
+  size_t key_len = 0, auth_len = 0, discard_len = 0;
 
   if (read_ciphers[idx].key != NULL) {
     /* If we have an existing key, it means that we are currently rekeying. */
@@ -437,7 +492,7 @@ int proxy_ssh_cipher_set_read_algo(pool *p, const char *algo) {
   }
 
   read_ciphers[idx].cipher = proxy_ssh_crypto_get_cipher(algo, &key_len,
-    &discard_len);
+    &auth_len, &discard_len);
   if (read_ciphers[idx].cipher == NULL) {
     return -1;
   }
@@ -448,6 +503,12 @@ int proxy_ssh_cipher_set_read_algo(pool *p, const char *algo) {
       (unsigned long) key_len);
   }
 
+  if (auth_len > 0) {
+    pr_trace_msg(trace_channel, 19,
+      "setting read key for cipher %s: auth len = %lu", algo,
+      (unsigned long) auth_len);
+  }
+
   if (discard_len > 0) {
     pr_trace_msg(trace_channel, 19,
       "setting read key for cipher %s: discard len = %lu", algo,
@@ -467,6 +528,7 @@ int proxy_ssh_cipher_set_read_algo(pool *p, const char *algo) {
   read_ciphers[idx].algo = pstrdup(read_ciphers[idx].pool, algo);
 
   read_ciphers[idx].key_len = (uint32_t) key_len;
+  read_ciphers[idx].auth_len = (uint32_t) auth_len;
   read_ciphers[idx].discard_len = discard_len;
   return 0;
 }
@@ -477,7 +539,7 @@ int proxy_ssh_cipher_set_read_key(pool *p, const EVP_MD *md,
   const unsigned char *id = NULL;
   char letter;
   uint32_t id_len;
-  int key_len;
+  int key_len, auth_len;
   struct proxy_ssh_cipher *cipher;
   EVP_CIPHER_CTX *pctx;
 
@@ -533,6 +595,23 @@ int proxy_ssh_cipher_set_read_key(pool *p, const EVP_MD *md,
     return -1;
   }
 
+  auth_len = (int) cipher->auth_len;
+  if (auth_len > 0) {
+#if defined(EVP_CTRL_GCM_SET_IV_FIXED)
+    if (EVP_CIPHER_CTX_ctrl(pctx, EVP_CTRL_GCM_SET_IV_FIXED, -1,
+        cipher->iv) != 1) {
+      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+        "error configuring %s cipher for decryption: %s", cipher->algo,
+        proxy_ssh_crypto_get_errors());
+      return -1;
+    }
+#endif /* EVP_CTRL_GCM_SET_IV_FIXED */
+
+    pr_trace_msg(trace_channel, 19,
+      "set auth length (%d) for %s cipher for decryption", auth_len,
+      cipher->algo);
+  }
+
   /* Next, set the key length. */
   key_len = (int) cipher->key_len;
   if (key_len > 0) {
@@ -564,63 +643,157 @@ int proxy_ssh_cipher_set_read_key(pool *p, const EVP_MD *md,
   }
 
   if (strcmp(cipher->algo, "aes128-ctr") == 0 ||
+      strcmp(cipher->algo, "aes128-gcm@openssh.com") == 0 ||
       strcmp(cipher->algo, "aes192-ctr") == 0 ||
-      strcmp(cipher->algo, "aes256-ctr") == 0) {
+      strcmp(cipher->algo, "aes256-ctr") == 0 ||
+      strcmp(cipher->algo, "aes256-gcm@openssh.com") == 0) {
     /* For some reason, OpenSSL returns 8 for the AES CTR/GCM block size (even
      * though the AES block size is 16, per RFC 5647), but OpenSSH wants 16.
      */
-    proxy_ssh_cipher_set_block_size(16);
+    proxy_ssh_cipher_set_read_block_size(16);
 
   } else {
-    proxy_ssh_cipher_set_block_size(EVP_CIPHER_block_size(cipher->cipher));
+    proxy_ssh_cipher_set_read_block_size(EVP_CIPHER_block_size(cipher->cipher));
   }
 
   return 0;
 }
 
-int proxy_ssh_cipher_read_data(pool *p, unsigned char *data, uint32_t data_len,
-    unsigned char **buf, uint32_t *buflen) {
+int proxy_ssh_cipher_read_data(struct proxy_ssh_packet *pkt,
+    unsigned char *data, uint32_t data_len, unsigned char **buf,
+    uint32_t *buflen) {
   struct proxy_ssh_cipher *cipher;
   EVP_CIPHER_CTX *pctx;
-  size_t cipher_blocksz;
+  size_t auth_len, read_blocksz;
+  uint32_t output_buflen;
 
   cipher = &(read_ciphers[read_cipher_idx]);
   pctx = read_ctxs[read_cipher_idx];
-  cipher_blocksz = cipher_blockszs[read_cipher_idx];
+  read_blocksz = read_blockszs[read_cipher_idx];
+  auth_len = proxy_ssh_cipher_get_read_auth_size();
+  output_buflen = *buflen;
 
   if (cipher->key != NULL) {
     int res;
-    unsigned char *ptr = NULL;
-
-    if (*buflen % cipher_blocksz != 0) {
-      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-        "bad input length for decryption (%u bytes, %u block size)", *buflen,
-        (unsigned int) cipher_blocksz);
-      return -1;
-    }
+    unsigned char *ptr = NULL, *buf2 = NULL;
 
     if (*buf == NULL) {
       size_t bufsz;
 
       /* Allocate a buffer that's large enough. */
-      bufsz = (data_len + cipher_blocksz - 1);
-      ptr = palloc(p, bufsz);
+      bufsz = (data_len + read_blocksz - 1);
+      ptr = buf2 = pcalloc(pkt->pool, bufsz);
 
     } else {
-      ptr = *buf;
+      ptr = buf2 = *buf;
     }
 
-    res = EVP_Cipher(pctx, ptr, data, data_len);
-    if (res != 1) {
+    if (pkt->packet_len == 0) {
+      if (auth_len > 0) {
+#if defined(EVP_CTRL_GCM_IV_GEN)
+        unsigned char prev_iv[1];
+
+        /* Increment the IV. */
+        if (EVP_CIPHER_CTX_ctrl(pctx, EVP_CTRL_GCM_IV_GEN, 1, prev_iv) != 1) {
+          (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+            "error incrementing %s IV data for server: %s", cipher->algo,
+            proxy_ssh_crypto_get_errors());
+          errno = EIO;
+          return -1;
+        }
+#endif
+      }
+
+      if (pkt->aad_len > 0 &&
+          pkt->aad == NULL) {
+        pkt->aad = pcalloc(pkt->pool, pkt->aad_len);
+        memcpy(pkt->aad, data, pkt->aad_len);
+        memcpy(ptr, data, pkt->aad_len);
+
+        /* Save room at the start of the output buffer `ptr` for the AAD
+         * bytes.
+         */
+        buf2 += pkt->aad_len;
+        data += pkt->aad_len;
+        data_len -= pkt->aad_len;
+        output_buflen -= pkt->aad_len;
+
+        if (auth_len > 0) {
+          if (EVP_Cipher(pctx, NULL, pkt->aad, pkt->aad_len) < 0) {
+            (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+              "error setting %s AAD data for server: %s", cipher->algo,
+              proxy_ssh_crypto_get_errors());
+            errno = EIO;
+            return -1;
+          }
+        }
+      }
+    }
+
+    if (output_buflen % read_blocksz != 0) {
       (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
-        "error decrypting %s data from client: %s", cipher->algo,
+        "bad input length for decryption (%u bytes, %lu AAD bytes, "
+        "%u block size)", output_buflen, (unsigned long) pkt->aad_len,
+        (unsigned int) read_blocksz);
+      return -1;
+    }
+
+    if (pkt->packet_len > 0 &&
+        auth_len > 0) {
+      unsigned char *tag_data = NULL;
+      uint32_t tag_datalen = auth_len;
+
+      /* The authentication tag appears after the unencrypted AAD bytes, and
+       * the encrypted payload bytes.
+       */
+      tag_data = data + (data_len - auth_len);
+
+#if defined(EVP_CTRL_GCM_GET_TAG)
+      if (EVP_CIPHER_CTX_ctrl(pctx, EVP_CTRL_GCM_SET_TAG, tag_datalen,
+          tag_data) != 1) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "error setting %s authentication tag for server: %s", cipher->algo,
+          proxy_ssh_crypto_get_errors());
+        errno = EIO;
+        return -1;
+      }
+#endif
+
+      data_len -= auth_len;
+    }
+
+    res = EVP_Cipher(pctx, buf2, data, data_len);
+    if (res < 0) {
+      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+        "error decrypting %s data from server: %s", cipher->algo,
         proxy_ssh_crypto_get_errors());
       return -1;
     }
 
-    *buflen = data_len;
+    if (pkt->packet_len > 0) {
+      *buflen = data_len;
+
+    } else {
+      /* If we don't know the packet length yet, it means we need to allow for
+       * the processing of the AAD bytes.
+       */
+      *buflen = pkt->aad_len + data_len;
+    }
+
     *buf = ptr;
 
+    if (pkt->packet_len > 0 &&
+        auth_len > 0) {
+      /* Verify the authentication tag, but only if we have the full packet. */
+      if (EVP_Cipher(pctx, NULL, NULL, 0) < 0) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "error verifying %s authentication tag for server: %s", cipher->algo,
+          proxy_ssh_crypto_get_errors());
+        errno = EIO;
+        return -1;
+      }
+    }
+
     return 0;
   }
 
@@ -640,7 +813,7 @@ const char *proxy_ssh_cipher_get_write_algo(void) {
 
 int proxy_ssh_cipher_set_write_algo(pool *p, const char *algo) {
   unsigned int idx = write_cipher_idx;
-  size_t key_len = 0, discard_len = 0;
+  size_t key_len = 0, auth_len = 0, discard_len = 0;
 
   if (write_ciphers[idx].key != NULL) {
     /* If we have an existing key, it means that we are currently rekeying. */
@@ -648,7 +821,7 @@ int proxy_ssh_cipher_set_write_algo(pool *p, const char *algo) {
   }
 
   write_ciphers[idx].cipher = proxy_ssh_crypto_get_cipher(algo, &key_len,
-    &discard_len);
+    &auth_len, &discard_len);
   if (write_ciphers[idx].cipher == NULL) {
     return -1;
   }
@@ -659,6 +832,12 @@ int proxy_ssh_cipher_set_write_algo(pool *p, const char *algo) {
       (unsigned long) key_len);
   }
 
+  if (auth_len > 0) {
+    pr_trace_msg(trace_channel, 19,
+      "setting write key for cipher %s: auth len = %lu", algo,
+      (unsigned long) auth_len);
+  }
+
   if (discard_len > 0) {
     pr_trace_msg(trace_channel, 19,
       "setting write key for cipher %s: discard len = %lu", algo,
@@ -678,6 +857,7 @@ int proxy_ssh_cipher_set_write_algo(pool *p, const char *algo) {
   write_ciphers[idx].algo = pstrdup(write_ciphers[idx].pool, algo);
 
   write_ciphers[idx].key_len = (uint32_t) key_len;
+  write_ciphers[idx].auth_len = (uint32_t) auth_len;
   write_ciphers[idx].discard_len = discard_len;
   return 0;
 }
@@ -688,7 +868,7 @@ int proxy_ssh_cipher_set_write_key(pool *p, const EVP_MD *md,
   const unsigned char *id = NULL;
   char letter;
   uint32_t id_len;
-  int key_len;
+  int key_len, auth_len;
   struct proxy_ssh_cipher *cipher;
   EVP_CIPHER_CTX *pctx;
 
@@ -744,6 +924,23 @@ int proxy_ssh_cipher_set_write_key(pool *p, const EVP_MD *md,
     return -1;
   }
 
+  auth_len = (int) cipher->auth_len;
+  if (auth_len > 0) {
+#if defined(EVP_CTRL_GCM_SET_IV_FIXED)
+    if (EVP_CIPHER_CTX_ctrl(pctx, EVP_CTRL_GCM_SET_IV_FIXED, -1,
+        cipher->iv) != 1) {
+      (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+        "error configuring %s cipher for encryption: %s", cipher->algo,
+        proxy_ssh_crypto_get_errors());
+      return -1;
+    }
+#endif /* EVP_CTRL_GCM_SET_IV_FIXED */
+
+    pr_trace_msg(trace_channel, 19,
+      "set auth length (%d) for %s cipher for encryption", auth_len,
+      cipher->algo);
+  }
+
   /* Next, set the key length. */
   key_len = (int) cipher->key_len;
   if (key_len > 0) {
@@ -774,6 +971,24 @@ int proxy_ssh_cipher_set_write_key(pool *p, const EVP_MD *md,
     return -1;
   }
 
+  if (strcmp(cipher->algo, "aes128-ctr") == 0 ||
+      strcmp(cipher->algo, "aes128-gcm@openssh.com") == 0 ||
+      strcmp(cipher->algo, "aes192-ctr") == 0 ||
+      strcmp(cipher->algo, "aes256-ctr") == 0 ||
+      strcmp(cipher->algo, "aes256-gcm@openssh.com") == 0) {
+    /* For some reason, OpenSSL returns 8 for the AES CTR/GCM block size (even
+     * though the AES block size is 16, per RFC 5647), but OpenSSH wants 16.
+     */
+    proxy_ssh_cipher_set_write_block_size(16);
+
+  } else {
+    proxy_ssh_cipher_set_write_block_size(EVP_CIPHER_block_size(cipher->cipher));
+  }
+
+  pr_trace_msg(trace_channel, 19,
+    "set block size (%d) for %s cipher for encryption",
+    (int) proxy_ssh_cipher_get_write_block_size(), cipher->algo);
+
   return 0;
 }
 
@@ -781,9 +996,11 @@ int proxy_ssh_cipher_write_data(struct proxy_ssh_packet *pkt,
     unsigned char *buf, size_t *buflen) {
   struct proxy_ssh_cipher *cipher;
   EVP_CIPHER_CTX *pctx;
+  size_t auth_len = 0;
 
   cipher = &(write_ciphers[write_cipher_idx]);
   pctx = write_ctxs[write_cipher_idx];
+  auth_len = proxy_ssh_cipher_get_write_auth_size();
 
   if (cipher->key != NULL) {
     int res;
@@ -793,10 +1010,56 @@ int proxy_ssh_cipher_write_data(struct proxy_ssh_packet *pkt,
     /* Always leave a little extra room in the buffer. */
     datasz = sizeof(uint32_t) + pkt->packet_len + 64;
 
+    if (pkt->aad_len > 0) {
+      /* Packet length is not encrypted for authentication encryption, or
+       * Encrypt-Then-MAC modes.
+       */
+      datasz -= pkt->aad_len;
+
+      /* And, for ETM modes, we may need a little more space. */
+      datasz += proxy_ssh_cipher_get_write_block_size();
+    }
+
     datalen = datasz;
     ptr = data = palloc(pkt->pool, datasz);
 
-    len += proxy_ssh_msg_write_int(&data, &datalen, pkt->packet_len);
+    if (auth_len > 0) {
+#if defined(EVP_CTRL_GCM_IV_GEN)
+      unsigned char prev_iv[1];
+
+      /* Increment the IV. */
+      if (EVP_CIPHER_CTX_ctrl(pctx, EVP_CTRL_GCM_IV_GEN, 1, prev_iv) != 1) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "error incrementing %s IV data for server: %s", cipher->algo,
+          proxy_ssh_crypto_get_errors());
+        errno = EIO;
+        return -1;
+      }
+#endif
+    }
+
+    if (pkt->aad_len > 0 &&
+        pkt->aad == NULL) {
+      uint32_t packet_len;
+
+      packet_len = htonl(pkt->packet_len);
+      pkt->aad = pcalloc(pkt->pool, pkt->aad_len);
+      memcpy(pkt->aad, &packet_len, pkt->aad_len);
+
+      if (auth_len > 0) {
+        if (EVP_Cipher(pctx, NULL, pkt->aad, pkt->aad_len) < 0) {
+          (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+            "error setting %s AAD (%lu bytes) for server: %s", cipher->algo,
+            (unsigned long) pkt->aad_len, proxy_ssh_crypto_get_errors());
+          errno = EIO;
+          return -1;
+        }
+      }
+
+    } else {
+      len += proxy_ssh_msg_write_int(&data, &datalen, pkt->packet_len);
+    }
+
     len += proxy_ssh_msg_write_byte(&data, &datalen, pkt->padding_len);
     len += proxy_ssh_msg_write_data(&data, &datalen, pkt->payload,
       pkt->payload_len, FALSE);
@@ -804,7 +1067,7 @@ int proxy_ssh_cipher_write_data(struct proxy_ssh_packet *pkt,
       pkt->padding_len, FALSE);
 
     res = EVP_Cipher(pctx, buf, ptr, len);
-    if (res != 1) {
+    if (res < 0) {
       (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
         "error encrypting %s data for server: %s", cipher->algo,
         proxy_ssh_crypto_get_errors());
@@ -832,6 +1095,36 @@ int proxy_ssh_cipher_write_data(struct proxy_ssh_packet *pkt,
 }
 #endif
 
+    if (auth_len > 0) {
+      unsigned char *tag_data = NULL;
+      uint32_t tag_datalen = 0;
+
+      if (EVP_Cipher(pctx, NULL, NULL, 0) < 0) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "error generating %s authentication tag for server: %s", cipher->algo,
+          proxy_ssh_crypto_get_errors());
+        errno = EIO;
+        return -1;
+      }
+
+      tag_datalen = auth_len;
+      tag_data = pcalloc(pkt->pool, tag_datalen);
+
+#if defined(EVP_CTRL_GCM_GET_TAG)
+      if (EVP_CIPHER_CTX_ctrl(pctx, EVP_CTRL_GCM_GET_TAG, tag_datalen,
+          tag_data) != 1) {
+        (void) pr_log_writefile(proxy_logfd, MOD_PROXY_VERSION,
+          "error getting %s authentication tag for server: %s", cipher->algo,
+          proxy_ssh_crypto_get_errors());
+        errno = EIO;
+        return -1;
+      }
+#endif
+
+      pkt->mac_len = tag_datalen;
+      pkt->mac = tag_data;
+    }
+
     return 0;
   }
 
