@@ -1,6 +1,6 @@
 /*
  * ProFTPD - mod_proxy testsuite
- * Copyright (c) 2016-2021 TJ Saunders <tj@castaglia.org>
+ * Copyright (c) 2016-2022 TJ Saunders <tj@castaglia.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,13 +89,13 @@ START_TEST (session_free_test) {
   int res;
 
   res = proxy_session_free(NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   res = proxy_session_free(p, NULL);
-  fail_unless(res < 0, "Failed to handle null session");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null session");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 }
 END_TEST
@@ -104,21 +104,21 @@ START_TEST (session_alloc_test) {
   struct proxy_session *proxy_sess;
 
   proxy_sess = (struct proxy_session *) proxy_session_alloc(NULL);
-  fail_unless(proxy_sess == NULL, "Failed to handle null argument");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(proxy_sess == NULL, "Failed to handle null argument");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   proxy_sess = (struct proxy_session *) proxy_session_alloc(p);
-  fail_unless(proxy_sess != NULL, "Failed to allocate proxy session: %s",
+  ck_assert_msg(proxy_sess != NULL, "Failed to allocate proxy session: %s",
     strerror(errno));
-  fail_unless(proxy_sess->use_ftp == TRUE, "Failed to use FTP by default");
-  fail_unless(proxy_sess->use_ssh == FALSE, "Failed to not use SSH by default");
+  ck_assert_msg(proxy_sess->use_ftp == TRUE, "Failed to use FTP by default");
+  ck_assert_msg(proxy_sess->use_ssh == FALSE, "Failed to not use SSH by default");
 
   mark_point();
   proxy_session_free(p, proxy_sess);
 
   proxy_sess = (struct proxy_session *) proxy_session_alloc(p);
-  fail_unless(proxy_sess != NULL, "Failed to allocate proxy session: %s",
+  ck_assert_msg(proxy_sess != NULL, "Failed to allocate proxy session: %s",
     strerror(errno));
 
   proxy_sess->frontend_data_conn = pr_inet_create_conn(p, -1, NULL, INPORT_ANY,
@@ -138,16 +138,16 @@ START_TEST (session_reset_dataxfer_test) {
   int res;
 
   res = proxy_session_reset_dataxfer(NULL);
-  fail_unless(res < 0, "Failed to handle null proxy_sess");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null proxy_sess");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 
   proxy_sess = (struct proxy_session *) proxy_session_alloc(p);
-  fail_unless(proxy_sess != NULL, "Failed to allocate proxy session: %s",
+  ck_assert_msg(proxy_sess != NULL, "Failed to allocate proxy session: %s",
     strerror(errno));
 
   res = proxy_session_reset_dataxfer(proxy_sess);
-  fail_unless(res == 0, "Failed to reset proxy session dataxfer: %s",
+  ck_assert_msg(res == 0, "Failed to reset proxy session dataxfer: %s",
     strerror(errno));
 
   mark_point();
@@ -161,30 +161,30 @@ START_TEST (session_check_password_test) {
 
   mark_point();
   res = proxy_session_check_password(NULL, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   res = proxy_session_check_password(p, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null user");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null user");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 
   user = "foo";
 
   mark_point();
   res = proxy_session_check_password(p, user, NULL);
-  fail_unless(res < 0, "Failed to handle null passwd");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null passwd");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 
   passwd = "bar";
 
   mark_point();
   res = proxy_session_check_password(p, user, passwd);
-  fail_unless(res < 0, "Failed to handle unknown user");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle unknown user");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 }
 END_TEST
@@ -195,18 +195,18 @@ START_TEST (session_setup_env_test) {
 
   mark_point();
   res = proxy_session_setup_env(NULL, NULL, flags);
-  fail_unless(res < 0, "Failed to handle null pool");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null pool");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   res = proxy_session_setup_env(p, NULL, flags);
-  fail_unless(res < 0, "Failed to handle null user");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null user");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got %s (%d)", EINVAL,
     strerror(errno), errno);
 
   session.c = pr_inet_create_conn(p, -1, NULL, INPORT_ANY, FALSE);
-  fail_unless(session.c != NULL,
+  ck_assert_msg(session.c != NULL,
     "Failed to open session control conn: %s", strerror(errno));
   session.c->remote_name = pstrdup(p, "127.0.0.1");
 
@@ -214,8 +214,8 @@ START_TEST (session_setup_env_test) {
 
   mark_point();
   res = proxy_session_setup_env(p, user, flags);
-  fail_unless(res == 0, "Failed to setup environment: %s", strerror(errno));
-  fail_unless(proxy_sess_state & PROXY_SESS_STATE_PROXY_AUTHENTICATED,
+  ck_assert_msg(res == 0, "Failed to setup environment: %s", strerror(errno));
+  ck_assert_msg(proxy_sess_state & PROXY_SESS_STATE_PROXY_AUTHENTICATED,
     "Expected PROXY_AUTHENTICATED state set");
 
   proxy_sess_state &= ~PROXY_SESS_STATE_PROXY_AUTHENTICATED;
@@ -224,8 +224,8 @@ START_TEST (session_setup_env_test) {
 
   mark_point();
   res = proxy_session_setup_env(p, user, flags);
-  fail_unless(res == 0, "Failed to setup environment: %s", strerror(errno));
-  fail_unless(proxy_sess_state & PROXY_SESS_STATE_PROXY_AUTHENTICATED,
+  ck_assert_msg(res == 0, "Failed to setup environment: %s", strerror(errno));
+  ck_assert_msg(proxy_sess_state & PROXY_SESS_STATE_PROXY_AUTHENTICATED,
     "Expected PROXY_AUTHENTICATED state set");
 
   proxy_sess_state &= ~PROXY_SESS_STATE_PROXY_AUTHENTICATED;
