@@ -1,6 +1,6 @@
 /*
  * ProFTPD - mod_proxy testsuite
- * Copyright (c) 2012-2021 TJ Saunders <tj@castaglia.org>
+ * Copyright (c) 2012-2022 TJ Saunders <tj@castaglia.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,39 +61,39 @@ START_TEST (uri_parse_args_test) {
 
   mark_point();
   res = proxy_uri_parse(NULL, NULL, NULL, NULL, NULL, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null pool");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null pool");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   res = proxy_uri_parse(p, NULL, NULL, NULL, NULL, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null URI");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null URI");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   uri = "foo";
   res = proxy_uri_parse(p, uri, NULL, NULL, NULL, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null scheme");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null scheme");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   res = proxy_uri_parse(p, uri, &scheme, NULL, NULL, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null host");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null host");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   res = proxy_uri_parse(p, uri, &scheme, &host, NULL, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle null port");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle null port");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle URI missing a colon");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle URI missing a colon");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -101,8 +101,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "foo:";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle unknown/unsupported scheme");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle unknown/unsupported scheme");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -110,8 +110,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "foo@:";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle illegal scheme character");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle illegal scheme character");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -119,8 +119,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "ftp:";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle URI lacking double slashes");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle URI lacking double slashes");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -128,8 +128,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "ftp:/";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle URI lacking double slashes");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle URI lacking double slashes");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -137,8 +137,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "ftp:/a";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle URI lacking double slashes");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle URI lacking double slashes");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -146,8 +146,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "ftp://";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle URI lacking hostname/port");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle URI lacking hostname/port");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -155,8 +155,8 @@ START_TEST (uri_parse_args_test) {
   port = 0;
   uri = "ftp://%2f";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to handle URI using URL encoding");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to handle URI using URL encoding");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 }
 END_TEST
@@ -172,72 +172,72 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://foo";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftp://foo:2121";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 2121,
+  ck_assert_msg(port == 2121,
     "Expected port '%u', got '%u'", 2121, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftp://127.0.0.1:2121";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "127.0.0.1") == 0,
+  ck_assert_msg(strcmp(host, "127.0.0.1") == 0,
     "Expected host '%s', got '%s'", "127.0.0.1", host);
-  fail_unless(port == 2121,
+  ck_assert_msg(port == 2121,
     "Expected port '%u', got '%u'", 2121, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftp://[::1]:2121";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "::1") == 0,
+  ck_assert_msg(strcmp(host, "::1") == 0,
     "Expected host '%s', got '%s'", "::1", host);
-  fail_unless(port == 2121,
+  ck_assert_msg(port == 2121,
     "Expected port '%u', got '%u'", 2121, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftp://[::1:2121";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res < 0, "Failed to reject URI with bad IPv6 host encoding");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to reject URI with bad IPv6 host encoding");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -245,19 +245,19 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://user:password@host:21";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "host") == 0,
+  ck_assert_msg(strcmp(host, "host") == 0,
     "Expected host '%s', got '%s'", "host", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username != NULL, "Expected non-null username");
-  fail_unless(strcmp(username, "user") == 0,
+  ck_assert_msg(username != NULL, "Expected non-null username");
+  ck_assert_msg(strcmp(username, "user") == 0,
     "Expected username '%s', got '%s'", "user", username);
-  fail_unless(password != NULL, "Expected non-null password");
-  fail_unless(strcmp(password, "password") == 0,
+  ck_assert_msg(password != NULL, "Expected non-null password");
+  ck_assert_msg(strcmp(password, "password") == 0,
     "Expected password '%s', got '%s'", "password", password);
 
   mark_point();
@@ -265,19 +265,19 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://user:@host:21";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "host") == 0,
+  ck_assert_msg(strcmp(host, "host") == 0,
     "Expected host '%s', got '%s'", "host", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username != NULL, "Expected non-null username");
-  fail_unless(strcmp(username, "user") == 0,
+  ck_assert_msg(username != NULL, "Expected non-null username");
+  ck_assert_msg(strcmp(username, "user") == 0,
     "Expected username '%s', got '%s'", "user", username);
-  fail_unless(password != NULL, "Expected non-null password");
-  fail_unless(strcmp(password, "") == 0,
+  ck_assert_msg(password != NULL, "Expected non-null password");
+  ck_assert_msg(strcmp(password, "") == 0,
     "Expected password '%s', got '%s'", "", password);
 
   mark_point();
@@ -285,35 +285,35 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://user@host:21";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "host") == 0,
+  ck_assert_msg(strcmp(host, "host") == 0,
     "Expected host '%s', got '%s'", "host", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftp://anonymous:email@example.com@host:21";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "host") == 0,
+  ck_assert_msg(strcmp(host, "host") == 0,
     "Expected host '%s', got '%s'", "host", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username != NULL, "Expected non-null username");
-  fail_unless(strcmp(username, "anonymous") == 0,
+  ck_assert_msg(username != NULL, "Expected non-null username");
+  ck_assert_msg(strcmp(username, "anonymous") == 0,
     "Expected username '%s', got '%s'", "anonymous", username);
-  fail_unless(password != NULL, "Expected non-null password");
-  fail_unless(strcmp(password, "email@example.com") == 0,
+  ck_assert_msg(password != NULL, "Expected non-null password");
+  ck_assert_msg(strcmp(password, "email@example.com") == 0,
     "Expected password '%s', got '%s'", "email@example.com", password);
 
   mark_point();
@@ -321,19 +321,19 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://user@domain:email@example.com@host:21";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "host") == 0,
+  ck_assert_msg(strcmp(host, "host") == 0,
     "Expected host '%s', got '%s'", "host", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username != NULL, "Expected non-null username");
-  fail_unless(strcmp(username, "user@domain") == 0,
+  ck_assert_msg(username != NULL, "Expected non-null username");
+  ck_assert_msg(strcmp(username, "user@domain") == 0,
     "Expected username '%s', got '%s'", "user@domain", username);
-  fail_unless(password != NULL, "Expected non-null password");
-  fail_unless(strcmp(password, "email@example.com") == 0,
+  ck_assert_msg(password != NULL, "Expected non-null password");
+  ck_assert_msg(strcmp(password, "email@example.com") == 0,
     "Expected password '%s', got '%s'", "email@example.com", password);
 
   mark_point();
@@ -341,8 +341,8 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://host:65555";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to reject URI with too-large port");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to reject URI with too-large port");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -350,24 +350,24 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://foo:2121/home";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp") == 0,
     "Expected scheme '%s', got '%s'", "ftp", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 2121,
+  ck_assert_msg(port == 2121,
     "Expected port '%u', got '%u'", 2121, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftp://host:65555:foo";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to reject URI with bad port spec");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to reject URI with bad port spec");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 
   mark_point();
@@ -375,8 +375,8 @@ START_TEST (uri_parse_ftp_test) {
   port = 0;
   uri = "ftp://host:70000";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to reject URI with invalid port spec");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to reject URI with invalid port spec");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 }
 END_TEST
@@ -392,48 +392,48 @@ START_TEST (uri_parse_ftps_test) {
   port = 0;
   uri = "ftps://foo";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftps") == 0,
+  ck_assert_msg(strcmp(scheme, "ftps") == 0,
     "Expected scheme '%s', got '%s'", "ftps", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 21,
+  ck_assert_msg(port == 21,
     "Expected port '%u', got '%u'", 21, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftps://foo:2121";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftps") == 0,
+  ck_assert_msg(strcmp(scheme, "ftps") == 0,
     "Expected scheme '%s', got '%s'", "ftps", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 2121,
+  ck_assert_msg(port == 2121,
     "Expected port '%u', got '%u'", 2121, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftps://foo:2121/home";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftps") == 0,
+  ck_assert_msg(strcmp(scheme, "ftps") == 0,
     "Expected scheme '%s', got '%s'", "ftps", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 2121,
+  ck_assert_msg(port == 2121,
     "Expected port '%u', got '%u'", 2121, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 }
 END_TEST
 
@@ -448,48 +448,48 @@ START_TEST (uri_parse_sftp_test) {
   port = 0;
   uri = "sftp://foo";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "sftp") == 0,
+  ck_assert_msg(strcmp(scheme, "sftp") == 0,
     "Expected scheme '%s', got '%s'", "sftp", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 22,
+  ck_assert_msg(port == 22,
     "Expected port '%u', got '%u'", 22, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "sftp://foo:2222";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "sftp") == 0,
+  ck_assert_msg(strcmp(scheme, "sftp") == 0,
     "Expected scheme '%s', got '%s'", "sftp", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 2222,
+  ck_assert_msg(port == 2222,
     "Expected port '%u', got '%u'", 2222, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "sftp://foo:2222/home";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "sftp") == 0,
+  ck_assert_msg(strcmp(scheme, "sftp") == 0,
     "Expected scheme '%s', got '%s'", "sftp", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 2222,
+  ck_assert_msg(port == 2222,
     "Expected port '%u', got '%u'", 2222, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 }
 END_TEST
 
@@ -504,8 +504,8 @@ START_TEST (uri_parse_http_test) {
   port = 0;
   uri = "http://host";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, NULL, NULL);
-  fail_unless(res < 0, "Failed to reject URI with unsupported scheme");
-  fail_unless(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
+  ck_assert_msg(res < 0, "Failed to reject URI with unsupported scheme");
+  ck_assert_msg(errno == EINVAL, "Expected EINVAL (%d), got '%s' (%d)", EINVAL,
     strerror(errno), errno);
 }
 END_TEST
@@ -522,32 +522,32 @@ START_TEST (uri_parse_srv_test) {
   port = 0;
   uri = "ftp+srv://foo:2121/home";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp+srv") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp+srv") == 0,
     "Expected scheme '%s', got '%s'", "ftp+srv", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 0,
+  ck_assert_msg(port == 0,
     "Expected port '%u', got '%u'", 0, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftps+srv://foo.bar";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftps+srv") == 0,
+  ck_assert_msg(strcmp(scheme, "ftps+srv") == 0,
     "Expected scheme '%s', got '%s'", "ftps+srv", scheme);
-  fail_unless(strcmp(host, "foo.bar") == 0,
+  ck_assert_msg(strcmp(host, "foo.bar") == 0,
     "Expected host '%s', got '%s'", "foo.bar", host);
-  fail_unless(port == 0,
+  ck_assert_msg(port == 0,
     "Expected port '%u', got '%u'", 0, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 }
 END_TEST
 
@@ -563,32 +563,32 @@ START_TEST (uri_parse_txt_test) {
   port = 0;
   uri = "ftp+txt://foo:2121/home";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftp+txt") == 0,
+  ck_assert_msg(strcmp(scheme, "ftp+txt") == 0,
     "Expected scheme '%s', got '%s'", "ftp+txt", scheme);
-  fail_unless(strcmp(host, "foo") == 0,
+  ck_assert_msg(strcmp(host, "foo") == 0,
     "Expected host '%s', got '%s'", "foo", host);
-  fail_unless(port == 0,
+  ck_assert_msg(port == 0,
     "Expected port '%u', got '%u'", 0, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 
   mark_point();
   scheme = host = username = password = NULL;
   port = 0;
   uri = "ftps+txt://foo.bar";
   res = proxy_uri_parse(p, uri, &scheme, &host, &port, &username, &password);
-  fail_unless(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
+  ck_assert_msg(res == 0, "Expected successful parsing of URI '%s', got %s", uri,
     strerror(errno));
-  fail_unless(strcmp(scheme, "ftps+txt") == 0,
+  ck_assert_msg(strcmp(scheme, "ftps+txt") == 0,
     "Expected scheme '%s', got '%s'", "ftps+txt", scheme);
-  fail_unless(strcmp(host, "foo.bar") == 0,
+  ck_assert_msg(strcmp(host, "foo.bar") == 0,
     "Expected host '%s', got '%s'", "foo.bar", host);
-  fail_unless(port == 0,
+  ck_assert_msg(port == 0,
     "Expected port '%u', got '%u'", 0, port);
-  fail_unless(username == NULL, "Expected null username, got '%s'", username);
-  fail_unless(password == NULL, "Expected null password, got '%s'", password);
+  ck_assert_msg(username == NULL, "Expected null username, got '%s'", username);
+  ck_assert_msg(password == NULL, "Expected null password, got '%s'", password);
 }
 END_TEST
 
